@@ -33,10 +33,7 @@ int last_bkgnd_id = -99; /* last background chosen */
 Sound_Chunk *wav_click = 0;
 #endif
 Bowl *bowls[BOWL_COUNT]; /* all bowls */
-int  *next_blocks, next_blocks_size = 0; /* buffered game blocks for
-                                            games where all players
-                                            will receive the same
-                                            blocks */
+int  *next_blocks = NULL, next_blocks_size = 0; /* all receive same blocks */
 
 extern Sdl sdl;
 extern Config config;
@@ -106,7 +103,7 @@ int confirm( Font *font, char *str, int type )
                 }
                 else
                 if ( type == CONFIRM_PAUSE ) {
-                    if ( event.key.keysym.sym == SDLK_p ) {
+                    if ( event.key.keysym.sym == config.pause_key ) {
                         ret = 1; go_on = 0;
                         break;
                     }
@@ -256,16 +253,12 @@ updated to use the fade effect.
 */
 int  tetris_init()
 {
-    /* create next block list if desired and multiplayer */
-    if ( config.same_blocks_for_all && !config.expert &&
-         config.gametype >= 3 )
-    {
-        next_blocks_size = NEXT_BLOCKS_CHUNK_SIZE;
-        next_blocks = calloc( next_blocks_size, sizeof(int) );
-        fill_int_array_rand(next_blocks,
-                            0,next_blocks_size,
-                            0,BLOCK_COUNT-1);
-    }
+	/* create block buffer with several bags each containing all 7 
+	 * tetrominoes permuted randomly */
+	next_blocks_size = BLOCK_BAG_COUNT * BLOCK_COUNT;
+	next_blocks = calloc( next_blocks_size, sizeof(int) );
+	fill_random_block_bags( next_blocks, BLOCK_BAG_COUNT );
+
     /* create bowls according to the gametype */
     switch ( config.gametype ) {
         case GAME_DEMO:
@@ -315,13 +308,13 @@ int  tetris_init()
 void tetris_clear()
 {
     int i;
-    
-    if ( config.same_blocks_for_all && !config.expert &&
-         config.gametype >= 3 )
-    {
-        next_blocks_size = 0;
-        free( next_blocks );
-    }
+
+	if (next_blocks) {
+		next_blocks_size = 0;
+		free( next_blocks );
+		next_blocks = NULL;
+	}
+
     for ( i = 0; i < BOWL_COUNT; i++ ) {
         if ( bowls[i] ) 
             bowl_delete( bowls[i] );
@@ -381,22 +374,19 @@ void tetris_run()
                         if ( bowls[i] ) 
                             bowl_store_key( bowls[i], event.key.keysym.sym );
                     break;
-                case SDL_KEYUP:    
-                    switch ( event.key.keysym.sym ) {
+                case SDL_KEYUP:
+                    if (game_over)
+                        leave = 1;
+                    else if (event.key.keysym.sym == config.pause_key)
+                        request_pause = 1;
+                    else switch ( event.key.keysym.sym ) {
                         case SDLK_ESCAPE: 
-                            if ( game_over ) {
-                                leave = 1;
-                                break;
-                            }
                             escape = 1;
                             if ( confirm( large_font, _("End Game? y/n"), CONFIRM_YES_NO ) ) 
                                 for ( i = 0; i < BOWL_COUNT; i++ )
                                     if ( bowls[i] && !bowls[i]->game_over )
                                         bowl_finish_game( bowls[i] );
                             break;
-                         case SDLK_p:
-                             request_pause = 1;
-                             break;
                          case SDLK_f:
                              /* switch fullscreen */
                             config.fullscreen = !config.fullscreen;
